==> haskell-status-notifier-item-0.3.1.0-311.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-status-notifier-item.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 status-notifier-item
version:              0.3.1.0
visibility:           public
id:                   status-notifier-item-0.3.1.0-DXcaUDvxoT69eosdePaOrW
key:                  status-notifier-item-0.3.1.0-DXcaUDvxoT69eosdePaOrW
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/status-notifier-item#readme
synopsis:
    A wrapper over the StatusNotifierItem/libappindicator dbus specification

description:
    Please see the README on Github at <https://github.com/IvanMalison/status-notifier-item#readme>

category:             Desktop
abi:                  bf5e57094cbb15c11e79e12939ec43e8
exposed:              True
exposed-modules:
    StatusNotifier.Host.Service StatusNotifier.Item.Client
    StatusNotifier.Item.Service StatusNotifier.TH StatusNotifier.Util
    StatusNotifier.Watcher.Client StatusNotifier.Watcher.Constants
    StatusNotifier.Watcher.Service StatusNotifier.Watcher.Signals

hidden-modules:       Paths_status_notifier_item
import-dirs:          /usr/lib/ghc-9.6.6/site-local/status-notifier-item-0.3.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/status-notifier-item-0.3.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/status-notifier-item-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-status-notifier-item
hs-libraries:         HSstatus-notifier-item-0.3.1.0-DXcaUDvxoT69eosdePaOrW
depends:
    base-4.18.2.1 byte-order-0.1.3.1-C5ntMYmRR3u7ZnBepNo19H
    bytestring-0.11.5.3
    bytestring-to-vector-0.3.0.1-9jwVcD7wOVZFnDjTB91ZfR
    containers-0.6.7 dbus-1.3.3-11fa9uMK72Y1CHWrLdB8AG
    filepath-1.4.300.1 hslogger-1.3.2.0-H4OZ1FZbeeNMbSjFBgOfV
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-status-notifier-item/html/status-notifier-item.haddock

haddock-html:         /usr/share/doc/haskell-status-notifier-item/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-status-notifier-item-0.3.1.0-313-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-status-notifier-item.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 status-notifier-item
version:              0.3.1.0
visibility:           public
id:                   status-notifier-item-0.3.1.0-J5CDIQT3Ba69Y8zmhyoIc0
key:                  status-notifier-item-0.3.1.0-J5CDIQT3Ba69Y8zmhyoIc0
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/status-notifier-item#readme
synopsis:
    A wrapper over the StatusNotifierItem/libappindicator dbus specification

description:
    Please see the README on Github at <https://github.com/IvanMalison/status-notifier-item#readme>

category:             Desktop
abi:                  134503c9d66853c25f238f3630452b2b
exposed:              True
exposed-modules:
    StatusNotifier.Host.Service StatusNotifier.Item.Client
    StatusNotifier.Item.Service StatusNotifier.TH StatusNotifier.Util
    StatusNotifier.Watcher.Client StatusNotifier.Watcher.Constants
    StatusNotifier.Watcher.Service StatusNotifier.Watcher.Signals

hidden-modules:       Paths_status_notifier_item
import-dirs:          /usr/lib/ghc-9.6.6/site-local/status-notifier-item-0.3.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/status-notifier-item-0.3.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/status-notifier-item-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-status-notifier-item
hs-libraries:         HSstatus-notifier-item-0.3.1.0-J5CDIQT3Ba69Y8zmhyoIc0
depends:
    base-4.18.2.1 byte-order-0.1.3.1-3Bna16b6R7lANv36to4TB9
    bytestring-0.11.5.3
    bytestring-to-vector-0.3.0.1-8cT1OUjHalaAQo6n9gUfvg
    containers-0.6.7 dbus-1.3.3-INvnWTkkmrECqNpDSboXTA
    filepath-1.4.300.1 hslogger-1.3.2.0-1NkMetVZZQxCHjmQHJSTJK
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-status-notifier-item/html/status-notifier-item.haddock

haddock-html:         /usr/share/doc/haskell-status-notifier-item/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
